Consumer

Struct Consumer 

pub struct Consumer { /* private fields */ }
Reader for one protected group.

Authentication failure is sticky and ends the grouped track.

Implementations

Source

impl Consumer

pub fn sequence(&self) -> u64

The group’s sequence number.

pub fn poll_read_frame( &mut self, waiter: &Waiter, ) -> Poll<Result<Option<Frame>>>

Read the next decrypted frame, without blocking.

Errors

Error::Authentication ends this track. Error::Oversize or Error::Exhausted as for open, and net errors from the underlying group.

pub async fn read_frame(&mut self) -> Result<Option<Frame>>

Read the next decrypted frame.

Errors

Same as Self::poll_read_frame.