pub struct Consumer { /* private fields */ }Expand description
Reader for one protected group.
Authentication failure is sticky and ends the grouped track.
Implementations
Sourceimpl Consumer
impl Consumer
Sourcepub fn poll_read_frame(
&mut self,
waiter: &Waiter,
) -> Poll<Result<Option<Frame>>>
pub fn poll_read_frame( &mut self, waiter: &Waiter, ) -> Poll<Result<Option<Frame>>>
Read the next decrypted frame, without blocking.
Errors
Error::Authentication ends this track. Error::Oversize or
Error::Exhausted as for open, and net errors from the underlying group.
Sourcepub async fn read_frame(&mut self) -> Result<Option<Frame>>
pub async fn read_frame(&mut self) -> Result<Option<Frame>>